{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Samtools-merge",
            "doc": "Samtools is a suite of programs for interacting with high-throughput sequencing data",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.17--hd87286a_1",
                    "id": "#samtools-docker.yml"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.17"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/samtools"
                            ]
                        }
                    ],
                    "id": "#samtools-bioconda.yml"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "separate": true,
                        "itemSeparator": " ",
                        "shellQuote": false
                    },
                    "id": "#samtools-merge.cwl/in_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-merge.cwl/out_bam"
                }
            ],
            "baseCommand": [
                "samtools",
                "merge"
            ],
            "id": "#samtools-merge.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_bam)"
                    },
                    "id": "#samtools-merge.cwl/out_sam"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "This workflow merge BAM files per condition in parallel",
            "label": "merge-bam-parallel",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/bams"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/out_bam"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/bam_merge/out_sam",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/merged_bams"
                }
            ],
            "steps": [
                {
                    "run": "#samtools-merge.cwl",
                    "label": "Samtools-Merge",
                    "scatter": [
                        "#main/bam_merge/in_bam",
                        "#main/bam_merge/out_bam"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/bam_merge/in_bam"
                        },
                        {
                            "source": "#main/out_bam",
                            "id": "#main/bam_merge/out_bam"
                        }
                    ],
                    "out": [
                        "#main/bam_merge/out_sam"
                    ],
                    "id": "#main/bam_merge"
                }
            ],
            "id": "#main",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
